@@ -1,5 +1,5 @@
-# $Revision: 2.4 $
-# $Id: ISBN.pm,v 2.4 2007/03/14 07:37:38 comdog Exp $
+# $Revision: 2.7 $
+# $Id: ISBN.pm,v 2.7 2007/08/17 18:52:16 comdog Exp $
 package Business::ISBN;
 use strict;
 
@@ -68,7 +68,7 @@ use vars qw( $VERSION @ISA @EXPORT_OK %EXPORT_TAGS $debug %group_data
 	$MAX_GROUP_CODE_LENGTH %ERROR_TEXT );
 
 use Carp qw(carp croak cluck);
-use Exporter qw( import );
+use base qw(Exporter);
 
 use Business::ISBN::Data 1.09; # now a separate module
 # ugh, hack
@@ -106,8 +106,7 @@ BEGIN {
 		);
 	};
 	
-#$VERSION = sprintf "%d.%02d", q$Revision: 2.4 $ =~ m/(\d+) \. (\d+)/xg;
-$VERSION = "2.00_01";
+$VERSION = "2.02_01";
 
 sub INVALID_PREFIX         () { -4 };
 sub INVALID_GROUP_CODE     () { -2 };
@@ -358,8 +357,9 @@ sub _checksum_pos            { length( $_[0]->isbn ) - 1                      }
 
 =item is_valid_checksum
 
-Returns true for valid checksums and false otherwise. This does not guarantee
-that the rest of the ISBN is valid.
+Returns C<Business::ISBN::GOOD_ISBN> for valid checksums and
+C<Business::ISBN::BAD_CHECKSUM> otherwise. This does not guarantee
+that the rest of the ISBN is actually assigned to a book.
 
 =cut
 
@@ -560,8 +560,12 @@ sub _set_prefix
 
 sub _set_group_code     {   $_[0]->{'group_code'}     = $_[1];   }
 
+sub _set_group_code_string     {   $_[0]->{'group_code_string'}     = $_[1];   }
+
 sub _set_publisher_code {   $_[0]->{'publisher_code'} = $_[1];   }
 
+sub _set_publisher_code_string {   $_[0]->{'publisher_code_string'} = $_[1];   }
+
 sub _set_article_code   {   $_[0]->{'article_code'}   = $_[1];   }
 
 sub _set_checksum       {   $_[0]->{'checksum'}       = $_[1];   }
@@ -769,9 +773,7 @@ __END__
 
 =head1 TO DO
 
-* i would like to create the bar codes with the price extension:
-	for now:
-	https://www.lightningsource.com/LSISecure/PubResources/CoverSpecsEntry.asp
+* i would like to create the bar codes with the price extension
 
 =head1 SOURCE AVAILABILITY
 
